@@ -1,12 +1,14 @@
 # -*- coding:utf-8  -*-
 
+from pyextension import *
+
 def opensource(module='tkextension'):
     if module == 'tkextension' or module == '__init__':
         file = open('__init__.py')
         get = file.read()
         file.close()
         return get
-    elif module == 'blackboard':
+    elif module == 'blackboard index' or module == 'blackboard_index':
         file = open('blackboard.py')
         get = file.read()
         file.close()
@@ -16,7 +18,7 @@ def opensource(module='tkextension'):
         get = file.read()
         file.close()
         return get
-    elif module == 'timer':
+    elif module == 'timer index' or module == 'timer_index':
         file = open('timer.py')
         get = file.read()
         file.close()
@@ -26,11 +28,21 @@ def opensource(module='tkextension'):
         get = file.read()
         file.close()
         return get
+    elif module == 'tix.blackboard' or module == 'blackboard':
+        file = open('tix/blackboard.py')
+        get = file.read()
+        file.close()
+        return get
     elif module == 'tix.filedialog' or module == 'filedialog':
         file = open('tix/filedialog.py')
         get = file.read()
         file.close()
         return get
+    elif module == 'tix.timer' or module == 'timer':
+        file = open('tix/timer.py')
+        get = file.read()
+        file.close()
+        return get
     elif module == 'turtledrawer':
         file = open('turtledrawer.py')
         get = file.read()
